@@ -22,10 +22,10 @@
 #include <KActionCollection>
 #include <QApplication>
 #include <KLocalizedString>
+#include <KCrash>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
-
 #include "kwqtutor.h"
 #include "kwordquiz.h"
 #include "version.h"
@@ -56,6 +56,8 @@ int main(int argc, char *argv[])
 
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
